@@ -20,12 +20,6 @@
 package org.freeplane.view.swing.map;
 
 import java.awt.LayoutManager;
-import java.awt.Point;
 
 public interface INodeViewLayout extends LayoutManager {
-	Point getMainViewInPoint(NodeView view);
-
-	Point getMainViewOutPoint(NodeView view, NodeView targetView, Point destinationPoint);
-
-	void layoutNodeMotionListenerView(NodeMotionListenerView view);
 }
