@@ -2,13 +2,13 @@ package org.freeplane.plugin.bugreport;
 
 import java.util.logging.Logger;
 
-import org.freeplane.core.controller.Controller;
+import org.freeplane.features.mode.Controller;
 import org.freeplane.main.osgi.IControllerExtensionProvider;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 
 public class Activator implements BundleActivator {
-	private XmlRpcHandler handler;
+	private ReportGenerator handler;
 	private Logger parentLogger;
 
 	/*
@@ -17,11 +17,11 @@ public class Activator implements BundleActivator {
 	 */
 	public void start(final BundleContext context) throws Exception {
 		parentLogger = Logger.getAnonymousLogger().getParent();
-		handler = new XmlRpcHandler();
+		handler = new ReportGenerator();
 		parentLogger.addHandler(handler);
 		context.registerService(IControllerExtensionProvider.class.getName(), new IControllerExtensionProvider() {
-			public void installExtension(final Controller Controller) {
-				handler.setBugReportListener(new ManualBugReporter(Controller));
+			public void installExtension(Controller controller) {
+				handler.setBugReportListener(new ManualBugReporter());
 			}
 		}, null);
 	}
