@@ -5,23 +5,28 @@ package org.freeplane.plugin.script.proxy;
 
 import java.awt.Color;
 
-import org.freeplane.core.model.NodeModel;
-import org.freeplane.features.common.edge.EdgeController;
-import org.freeplane.features.common.edge.EdgeStyle;
-import org.freeplane.features.mindmapmode.MModeController;
-import org.freeplane.features.mindmapmode.edge.MEdgeController;
+import org.freeplane.core.util.ColorUtils;
+import org.freeplane.features.edge.EdgeController;
+import org.freeplane.features.edge.EdgeStyle;
+import org.freeplane.features.edge.mindmapmode.MEdgeController;
+import org.freeplane.features.map.NodeModel;
+import org.freeplane.plugin.script.ScriptContext;
 
 class EdgeProxy extends AbstractProxy<NodeModel> implements Proxy.Edge {
-	EdgeProxy(final NodeModel delegate, final MModeController modeController) {
-		super(delegate, modeController);
+	EdgeProxy(final NodeModel delegate, final ScriptContext scriptContext) {
+		super(delegate, scriptContext);
 	}
 
 	public Color getColor() {
 		return getEdgeController().getColor(getDelegate());
 	}
+	
+	public String getColorCode() {
+		return ColorUtils.colorToString(getColor());
+	}
 
 	private MEdgeController getEdgeController() {
-		return (MEdgeController) EdgeController.getController(getModeController());
+		return (MEdgeController) EdgeController.getController();
 	}
 
 	public EdgeStyle getType() {
@@ -36,6 +41,10 @@ class EdgeProxy extends AbstractProxy<NodeModel> implements Proxy.Edge {
 		getEdgeController().setColor(getDelegate(), color);
 	}
 
+	public void setColorCode(final String rgbString) {
+		setColor(ColorUtils.stringToColor(rgbString));
+	}
+
 	public void setType(final EdgeStyle type) {
 		getEdgeController().setStyle(getDelegate(), type);
 	}
