@@ -29,8 +29,7 @@ import org.apache.batik.svggen.SVGGeneratorContext;
 import org.apache.batik.svggen.SVGGraphics2D;
 import org.apache.batik.svggen.SVGGeneratorContext.GraphicContextDefaults;
 import org.apache.batik.util.SVGConstants;
-import org.freeplane.core.controller.Controller;
-import org.freeplane.features.mindmapmode.addins.export.ExportAction;
+import org.freeplane.features.export.mindmapmode.AExportEngine;
 import org.freeplane.view.swing.map.MapView;
 import org.w3c.dom.DOMImplementation;
 import org.w3c.dom.Document;
@@ -38,16 +37,11 @@ import org.w3c.dom.Document;
 /**
  * @author foltin
  */
-abstract class ExportVectorGraphic extends ExportAction {
+abstract class ExportVectorGraphic extends AExportEngine {
 	/**
 	 * 
 	 */
 	private static final long serialVersionUID = 1L;
-
-	public ExportVectorGraphic(final String key, final Controller controller) {
-		super(key, controller);
-	}
-
 	/**
 	 */
 	protected SVGGraphics2D fillSVGGraphics2D(final MapView view) {
@@ -68,6 +62,8 @@ abstract class ExportVectorGraphic extends ExportAction {
 		g2d.setSVGCanvasSize(new Dimension(innerBounds.width, innerBounds.height));
 		g2d.translate(-innerBounds.x, -innerBounds.y);
 		view.print(g2d);
+		view.endPrinting();
 		return g2d;
 	}
+
 }
